@@ -975,7 +975,7 @@ class User(Entity):
         """
         # FIXME Refactor
         headers = getHeaders(self)
-        url = url_join(API_ROOT, "/api/generic/", "share-link")
-        params = {"token": token, "get_single": 1}
-        requestService.get(url, headers=headers, params=params)
+        url = url_join(API_ROOT, "/api/generic/",
+                       "share-link", 'accept', token)
+        requestService.post(url, headers=headers)
         return None
