@@ -36,7 +36,7 @@ class UserRepository:
         return User(json.loads(response.content))
 
     def authenticate(self, username, apikey):
-        url = url_join(API_ROOT, "api/generic/user", urllib.parse.quote(username))
+        url = url_join(API_ROOT, "api/generic/user/info")
         response = requestService.get(url, headers={"apikey": apikey})
         user = json.loads(response.content)
         user["api_key"] = apikey
