@@ -21,7 +21,7 @@ def url_join(*args):
     return "/".join(arg.strip("/") for arg in args)
 
 
-def handleError(response):
+def handleError(response, *args, **kwargs):
     """
     Returns
     -------
